--[[
	Nas.lua
		Merchant automation
--]]

--[[
	Copyright (c) 2010 Philippe Mingo
	All rights reserved.

	Redistribution and use in source and binary forms, with or without 
	modification, are permitted provided that the following conditions are met:

		* Redistributions of source code must retain the above copyright notice, 
		  this list of conditions and the following disclaimer.
		* Redistributions in binary form must reproduce the above copyright
		  notice, this list of conditions and the following disclaimer in the 
		  documentation and/or other materials provided with the distribution.
		* Neither the name of the author nor the names of its contributors may 
		  be used to endorse or promote products derived from this software 
		  without specific prior written permission.

	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
	AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
	IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
	ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
	LIABLE FORANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
	CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
	SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
	INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
	CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
	ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
	POSSIBILITY OF SUCH DAMAGE.
--]]

local function dsp(...)

	local text = "|cff33ff99Nas|r:"
	local i;
	
	for i = 1, select("#", ...) do
		text = text .. " " .. tostring( select( i, ... ) )
	end
	print( text )
	
end

SLASH_NAS1 = '/nas';

local _, L = ...;

local sVersion = " 0.0.05 ";

local function nasGestor( msg, editbox )
   
    local cmd, txt = msg:match("^(%S*)%s*(.-)$");


    cmd = string.upper( cmd );
    
    if cmd == nil then
        Saluda( true );
    elseif cmd == string.upper( L["morning"] ) then
        NasConfig["morning"] = txt;
    elseif cmd == string.upper( L["afternoon"] ) then
        NasConfig["afternoon"] = txt;
    elseif cmd == string.upper( L["night"] ) then
        NasConfig["night"] = txt;
    elseif cmd == string.upper( L["hmorning"] ) then
        NasConfig["hmorning"] = tonumber( txt );
    elseif cmd == string.upper( L["hafternoon"] ) then
        NasConfig["hafternoon"] = tonumber( txt );
    elseif cmd == string.upper( L["hnight"] ) then
        NasConfig["hnight"] = tonumber( txt );
    elseif cmd == "CD" then
        NasCount["cd"] = tonumber( txt );
    elseif cmd == "AUTO" then
    	if string.upper( txt ) == string.upper( L["no"] ) then
    	   NasConfig["auto"] = L["no"]; 
    	else
    	   NasConfig["auto"] = L["yes"];
    	end        
    elseif cmd == "CONFIG" then
        dsp( L["Version"] .. sVersion .. " : " .. L["Configuration"] );
        for k,c in pairs( NasConfig ) do
            dsp( L[k] .. " " .. c );
        end        
        for k,c in pairs( NasCount ) do
            dsp( L[k] .. " " .. c );
        end
    elseif cmd == "?" or cmd == "HELP" then
        dsp( L["Version"] .. sVersion );
        dsp( "/nas ? or /nas help : " .. L["This information"] );
        dsp( "/nas cd : " .. L["Sets NAS cooldown in minutes"] );
        dsp( "/nas " .. L["morning"] .. " [" .. L["morning greeting"] .. "]" );
        dsp( "/nas " .. L["afternoon"] .. " [" .. L["afternoon greeting"] .. "]" );
        dsp( "/nas " .. L["night"] .. " [" .. L["night greeting"] .. "]" );
        dsp( "/nas " .. L["hnight"] .. " [" .. L["hour"] .. "] : " .. L["From midnight to hnight it's night"] );
        dsp( "/nas " .. L["hmorning"] .. " [" .. L["hour"] .. "] : " .. L["From hnight to hmorning it's morning"] );
        dsp( "/nas " .. L["hafternoon"] .. " [" .. L["hour"] .. "] : " .. L["From hmorning to hafternoon it's afternoon, and then night again"] );
        dsp( "/nas config : " .. L["Shows actual configuration"] );
        dsp( "/nas auto [" .. L["yes"] .. "/" .. L["no"] .. "] : " .. L["Tells nas if it should greet guild automatically on entering wow"] );
    else 
        Saluda( true );        
    end
    
end

SlashCmdList["NAS"] = nasGestor; 
         
function nasInicio() 

	this:RegisterEvent( "ADDON_LOADED" );
	this:RegisterEvent( "PLAYER_LOGIN" );
	this:RegisterEvent( "PLAYER_LOGOUT" );
	
end

function nasEvento( event, arg1 )

    if event == "ADDON_LOADED" then
            
        if arg1 == "Nas" then
        
            dsp( L["Version"] .. sVersion .. L["loaded"] );
            
            if NasConfig == nil then
                -- Cargamos los valores por omisión de saludo
                NasConfig = { morning = L["Good morning!"], 
                              afternoon = L["Good afternoon!"], 
                              night = L["Good night!"],
                              auto = L["si"],
                              hnight = tonumber( L["5"] ),
                              hmorning = tonumber( L["12"] ),
                              hafternoon = tonumber( L["21"] ) };
            end                                          

            NasConfig["hnight"] = tonumber( NasConfig["hnight"] );
            if NasConfig["hnight"] == nil then
                NasConfig["hnight"] = L["5"];
            end 
            NasConfig["hmorning"] = tonumber( NasConfig["hmorning"] );
            if NasConfig["hmorning"] == nil then
                NasConfig["hmorning"] = L["12"];
            end            
            NasConfig["hafternoon"] = tonumber( NasConfig["hafternoon"] );
            if NasConfig["hafternoon"] == nil then
                NasConfig["hafternoon"] = L["21"];
            end            
            
            if NasCount == nil then
                NasCount = { cd = 60,
                             ultimosaludo = 0 };            
            end 
                        
        end
        
    elseif event == "PLAYER_LOGIN" then

        if NasConfig["auto"] ~= L["no"] then    
            Saluda( false );
        end     
                
	end
	
end

function Saluda( bforzado )

    local fecha = tonumber( date( "%Y%m%d" ) ) * 10000;
    local hora = tonumber( date( "%H" ) );
    local minuto = tonumber( date( "%M" ) );
    
    local min = fecha + hora * 60 + minuto;

    if bforzado or                                              -- Flag de saludo obligatorio 
       NasCount["cd"] == 0 or                                   -- CD a 0 quiere decir SIEMPRE 
       min - NasCount["ultimosaludo"] >= NasCount["cd"] then    -- Han pasado mas de CD minutos    
        
        if hora < NasConfig["hnight"] then
            SendChatMessage( NasConfig["night"] ,"GUILD" );
        elseif hora < NasConfig["hmorning"] then
            SendChatMessage( NasConfig["morning"] ,"GUILD" );
        elseif hora < NasConfig["hafternoon"] then
            SendChatMessage( NasConfig["afternoon"] ,"GUILD" );
        else
            SendChatMessage( NasConfig["night"] ,"GUILD" );                
        end

        NasCount["ultimosaludo"] = min;
    
    end
            
end            
